@@ -5,48 +5,15 @@ var _chart_stats = null;
 var _stats_data = [];
 var initialized = false;
 
-var _bytes_human_readable = function(bytes, si) {
-	var thresh = si ? 1000 : 1024;
-	if(bytes < thresh) return bytes + ' B';
-	var units = si ? ['kB','MB','GB','TB','PB','EB','ZB','YB'] : ['KiB','MiB','GiB','TiB','PiB','EiB','ZiB','YiB'];
-	var u = -1;
-	do {
-		bytes /= thresh;
-		++u;
-	} while(bytes >= thresh);
-	return bytes.toFixed(1)+' '+units[u];
-};
-
-var _time_human_readable = function(d) {
-	str = '';
-	var days = Math.floor((d % 31536000) / 86400);
-	var hours = Math.floor(((d % 31536000) % 86400) / 3600);
-	var minutes = Math.floor((((d % 31536000) % 86400) % 3600) / 60);
-	var seconds = (((d % 31536000) % 86400) % 3600) % 60;
-	if (days > 0) {
-		str += days;
-		if (days > 1) {
-			str += ' days ';
-		} else {
-			str += ' day ';
-		}
-	}
-	if (hours > 0) {
-		str += pad(hours,2)+'H ';
-	}
-	str += pad(minutes,2)+'m '+pad(seconds,2)+'s';
-	return str;
-};
-
 var _client = function() {
 	if (!initialized) {
 		$.each(_charts, function(i, j) {
 			tmp = nv.models.stackedAreaChart()
-							.x(function(d) { return d[0] })
+							.x(function(d) { return d3.time.format.iso.parse(d[0]) })
 							.y(function(d) { return d[1] })
 							.useInteractiveGuideline(true)
 							.color(d3.scale.category20c().range())
-							.margin({bottom: 105, left: 80})
+							.margin({bottom: 115, left: 100})
 							;
 
 			tmp.xAxis.showMaxMin(true).tickFormat(function(d) { return d3.time.format('%x %X')(new Date(d)) }).rotateLabels(-45);
@@ -59,7 +26,8 @@ var _client = function() {
 					.color(d3.scale.category10().range())
 					.x(function(d,i) { return i })
 					.y(function(d) { return d[1] })
-					.margin({bottom: 105, left: 80})
+					.margin({bottom: 115, left: 100, right: 80})
+					.focusEnable(false)
 					;
 
 		_chart_stats.xAxis.tickFormat(function(d) {
@@ -71,9 +39,75 @@ var _client = function() {
 
 		_chart_stats.y2Axis.tickFormat(function(d) { return _bytes_human_readable(d, false) }); // Size
 
+		_chart_stats.tooltip.contentGenerator(function(d) {
+			if (d === null) {
+				return '';
+			}
+
+			var title = 'Bytes received';
+			var duration = false;
+			if ('data' in d) {
+				title = 'Duration';
+				duration = true;
+			}
+
+			var table = d3.select(document.createElement("table"));
+			var theadEnter = table.selectAll("thead")
+				.data([d])
+				.enter().append("thead");
+
+			theadEnter.append("tr")
+				.append("td")
+				.attr("colspan", 3)
+				.append("strong")
+				.classed("x-value", true)
+				.text(title);
+
+			var tbodyEnter = table.selectAll("tbody")
+				.data([d])
+				.enter().append("tbody");
+
+			var trowEnter = tbodyEnter.selectAll("tr")
+				.data(function(p) { return p.series})
+				.enter()
+				.append("tr")
+				.classed("highlight", function(p) { return p.highlight});
+
+			trowEnter.append("td")
+				.classed("legend-color-guide",true)
+				.append("div")
+				.style("background-color", function(p) { return p.color});
+
+			trowEnter.append("td")
+				.classed("key",true)
+				.classed("total",function(p) { return !!p.total})
+				.text(function(p, i) {
+					if (duration) {
+						return _time_human_readable(p.value);
+					}
+					return _bytes_human_readable(p.value, false);
+				});
+
+			trowEnter.selectAll("td").each(function(p) {
+				if (p.highlight) {
+				var opacityScale = d3.scale.linear().domain([0,1]).range(["#fff",p.color]);
+				var opacity = 0.6;
+				d3.select(this)
+					.style("border-bottom-color", opacityScale(opacity))
+					.style("border-top-color", opacityScale(opacity))
+				;
+				}
+			});
+
+			var html = table.node().outerHTML;
+			if (d.footer !== undefined)
+				html += "<div class='footer'>" + d.footer + "</div>";
+			return html;
+		});
+
 		_chart_stats.bars.forceY([0]);
 	}
-	url = '{{ url_for("client_stat_json", name=cname, server=server) }}';
+	url = '{{ url_for("api.client_report", name=cname, server=server) }}';
 	$.getJSON(url, function(d) {
 		var _fields = [ 'dir', 'files', 'hardlink', 'softlink', 'files_enc', 'meta', 'meta_enc', 'special', 'efs', 'vssheader', 'vssheader_enc', 'vssfooter', 'vssfooter_enc' ];
 		var stats = true;
@@ -84,31 +118,20 @@ var _client = function() {
 				size = [];
 				duration = [];
 				push = false;
-				if (!d.results) {
-					if (d.notif) {
-						$.each(d.notif, function(i, n) {
-							notif(n[0], n[1]);
-						});
-					}
-					$('.mycharts').each(function() {
-						$(this).parent().hide();
-					});
-					return;
-				}
 				$('.mycharts').each(function() {
 					$(this).parent().show();
 				});
-				$.each(d.results, function(a, j) {
+				$.each(d, function(a, j) {
 					if (j[c] !== undefined) {
 						val = parseFloat(j[c][l]);
-						values.push([ parseInt(j.end)*1000, val ]);
+						values.push([ j.end, val ]);
 						push = true;
 					} else {
-						values.push([ parseInt(j.end), 0 ]);
+						values.push([ j.end, 0 ]);
 					}
 					if (stats) {
-						size.push([ parseInt(j.end)*1000, j.received ]);
-						duration.push([ parseInt(j.end)*1000, j.duration ]);
+						size.push([ j.end, j.received ]);
+						duration.push([ j.end, j.duration ]);
 					}
 				});
 				if (stats) {
@@ -126,16 +149,22 @@ var _client = function() {
 				if (c.key === 'chart_'+l) {
 					if (data.length > 0) {
 						c.data = data;
-						$('#chart_'+l).parent().show();
+						$('#chart_'+l).parent().parent().show();
 					} else {
-						$('#chart_'+l).parent().hide();
+						$('#chart_'+l).parent().parent().hide();
 					}
 					return false;
 				}
 			});
 		});
+		_redraw();
+	})
+	.fail(buiFail)
+	.fail(function() {
+		$('.mycharts').each(function() {
+			$(this).parent().hide();
+		});
 	});
-	_redraw();
 };
 
 var _redraw = function() {
